
-- Author: Ian898
-- Date: 20/06/2018

lightHudAddon = {}
lightHudAddon.modDirectory = g_currentModDirectory

function lightHudAddon.prerequisitesPresent(specializations)
	return true
end

function lightHudAddon:load(xmlFile)
	local uiScale = g_gameSettings:getValue("uiScale")
	
	local vehicleHudBgX = g_currentMission.vehicleHudBg.x
	local vehicleHudBgY = g_currentMission.vehicleHudBg.y
	local vehicleHudBgH = g_currentMission.vehicleHudBg.height
	local vehicleHudBgW = g_currentMission.vehicleHudBg.width
	
	local atlasFilename = Utils.getFilename("lightHudAddon.png", lightHudAddon.modDirectory)
	
	local width, height = getNormalizedScreenValues(15*uiScale, 15*uiScale)
	local offsetX, offsetY = getNormalizedScreenValues(4*uiScale, 4*uiScale)
	local x = vehicleHudBgX + offsetX
	local y = vehicleHudBgY + offsetY
	self.leftTurnSignalOverlay = Overlay:new("leftTurnSignalOverlay", atlasFilename, x, y, width, height)
	self.leftTurnSignalOverlay:setUVs(getNormalizedUVs({170, 32, 32, 32},{256, 32}))
	
	local x = vehicleHudBgX + vehicleHudBgW - offsetX - width
	local y = vehicleHudBgY + offsetY
	self.rightTurnSignalOverlay = Overlay:new("rightTurnSignalOverlay", atlasFilename, x, y, width, height)
	self.rightTurnSignalOverlay:setUVs(getNormalizedUVs({204, 32, 32, 32},{256, 32}))
	
	local offsetX, offsetY = getNormalizedScreenValues(4*uiScale, 45*uiScale)
	local x = vehicleHudBgX + offsetX
	local y = vehicleHudBgY + offsetY
	
	self.beaconLightOverlay = Overlay:new("beaconLightOverlay", atlasFilename, x, y, width, height)
	self.beaconLightOverlay:setUVs(getNormalizedUVs({0, 32, 32, 32},{256, 32}))
	
	self.lowLightOverlay = Overlay:new("lowLightOverlay", atlasFilename, x + (width*1), y, width, height)
	self.lowLightOverlay:setUVs(getNormalizedUVs({34, 32, 32, 32},{256, 32}))
	
	self.highLightOverlay = Overlay:new("highLightOverlay", atlasFilename, x + (width*2), y, width, height)
	self.highLightOverlay:setUVs(getNormalizedUVs({68, 32, 32, 32},{256, 32}))
	
	self.frontWorkLightOverlay = Overlay:new("frontWorkLightOverlay", atlasFilename, x + (width*3), y, width, height)
	self.frontWorkLightOverlay:setUVs(getNormalizedUVs({102, 32, 32, 32},{256, 32}))
	
	self.backWorkLightOverlay = Overlay:new("backWorkLightOverlay", atlasFilename, x + (width*4), y, width, height)
	self.backWorkLightOverlay:setUVs(getNormalizedUVs({136, 32, 32, 32},{256, 32}))
	
	if g_currentMission.opravaHudTipperOverlay == nil then
		g_currentMission.hudTipperOverlay.x = g_currentMission.hudTipperOverlay.x - (0.005*uiScale)
		g_currentMission.opravaHudTipperOverlay=true
	end
	
	if g_currentMission.opravaHudAttachOverlay == nil then
		g_currentMission.hudAttachmentOverlay.x = g_currentMission.hudAttachmentOverlay.x - (0.005*uiScale)
		g_currentMission.opravaHudAttachOverlay=true
	end
end

function lightHudAddon:update(dt)
end

function lightHudAddon:keyEvent(unicode, sym, modifier, isDown)
end

function lightHudAddon:mouseEvent(posX, posY, isDown, isUp, button)
end

function lightHudAddon:delete()
	self.leftTurnSignalOverlay:delete()
	self.rightTurnSignalOverlay:delete()
	self.beaconLightOverlay:delete()
	self.lowLightOverlay:delete()
	self.highLightOverlay:delete()
	self.frontWorkLightOverlay:delete()
	self.backWorkLightOverlay:delete()
end

function lightHudAddon:getActiveLights(lightType)
	if lightType ~= nil then
		if lightType == 1 then
			return { low=true, high=false, front=false, back=false }
		end
		if lightType == 2 then
			return { low=false, high=false, front=false, back=true }
		end
		if lightType == 3 then
			return { low=true, high=false, front=false, back=true }
		end
		if lightType == 4 then
			return { low=false, high=false, front=true, back=false }
		end
		if lightType == 5 then
			return { low=true, high=false, front=true, back=false }
		end
		if lightType == 6 then
			return { low=false, high=false, front=true, back=true }
		end
		if lightType == 7 then
			return { low=true, high=false, front=true, back=true }
		end
		if lightType == 8 then
			return { low=false, high=true, front=false, back=false }
		end
		if lightType == 9 then
			return { low=true, high=true, front=false, back=false }
		end
		if lightType == 10 then
			return { low=false, high=true, front=false, back=true }
		end
		if lightType == 11 then
			return { low=true, high=true, front=false, back=true }
		end
		if lightType == 12 then
			return { low=false, high=true, front=true, back=false }
		end
		if lightType == 13 then
			return { low=true, high=true, front=true, back=false }
		end
		if lightType == 15 then
			return { low=true, high=true, front=true, back=true }
		end
	end
	return { low=false, high=false, front=false, back=false }
end

function lightHudAddon:draw()
	
	-- Lights	
	local lightActive = lightHudAddon:getActiveLights(self.lightsTypesMask)
	if lightActive.low then
		self.lowLightOverlay:render()
	end
	if lightActive.high then
		self.highLightOverlay:render()
	end
	if lightActive.front then
		self.frontWorkLightOverlay:render()
	end
	if lightActive.back then
		self.backWorkLightOverlay:render()
	end
	
	-- Turn Lights
	if self.turnLightState~=nil and self.turnLightState > 0 then
		local turnLightTimer = Utils.clamp( math.cos( 7.0 * ( g_currentMission.time/1000 ) ) + 0.2, 0, 1)		
		if self.turnLightState == 1 or self.turnLightState == 3 then
			if turnLightTimer == 0 then
				self.leftTurnSignalOverlay:render()
			end
		end
		if self.turnLightState == 2 or self.turnLightState == 3 then
			if turnLightTimer == 0 then
				self.rightTurnSignalOverlay:render()
			end
		end
	end
	
	-- Beacon Lights
	if (self.beaconLightsActive~=nil) and (self.beaconLightsActive) then
		self.beaconLightOverlay:render()
	end
end